@@ -1,5 +1,6 @@
 import json
 import pathlib
+from pathlib import Path
 
 __all__ = ["SprintScheduleStore"]
 
@@ -41,7 +42,7 @@ class SprintScheduleStore:
                 "The JSON file structure is invalid. Please check the documentation: https://github.com/SharryXu/jira-tool"
             )
 
-    def load_file(self, file: str):
+    def load_file(self, file: "str | Path"):
         """
         Load json file to generate the excel definition
 
